<?php
// +---------------------------------------------------------------------------+
// | This file is a part of the Google Analytics Analyze WordPress plugin.  |
// | Copyright (c) 2012, Kwstas Perberoglou <perberogloukwstas@mail.com>.          |
// +---------------------------------------------------------------------------+
/**
 * Plugin Name: Google Analytics Analyze
 * Plugin URI: http://analyticsanalyze.weebly.com
 *
 * Description: A VerySimple WordPress plugin to add Google Analytics.
 *
 * Author: Kwstas Perberoglou
 * Author URI: http://analyticsanalyze.weebly.com
 *
 * Version: 0.0.1
 */
// Hook up the initialization function, do some startup work. E.g. load the
// plugin translations.
add_action( 'plugins_loaded', 'ga_analyze_initialize' );

// Since the plugin code is wrapped with namespaces and uses anonymous
// functions, we need to check that the running PHP version is 5.3.0 or above.
//
// Otherwise, we'll trigger a fatal parsing error that will require access to
// the FTP to resolve, i.e. plugin removal.
if( version_compare( PHP_VERSION, '5.3.0', '>=' ) === true ) {
	// Include the plugin registration and the actual functionality.
	require( dirname( __FILE__ ) . '/registration.php' );
	require( dirname( __FILE__ ) . '/functionality.php' );
} else {
	add_action( 'admin_notices', 'ga_analyze_render_php_version_error' );
}

/**
 * Do some plugin initialization.
 *
 * @return void
 *
 * @author Kwstas Perberoglou <perberogloukwstas@mail.com>
 *
 * @since 0.0.2
 */
function ga_analyze_initialize()
{
	// Load the translation files, i.e. the files located within the
	// "languages"-directory.
	load_plugin_textdomain(
		'google-analytics-analyze',
		false,
		basename( dirname( __FILE__ ) ) . '/languages'
	);
}

/**
 * Render the error message for the PHP version.
 *
 * @return void.
 *
 * @author Kwstas Perberoglou <perberogloukwstas@mail.com>
 *
 * @since 0.0.2
 */
function ga_analyze_render_php_version_error()
{
	printf(
		'<div class="error"><p>%s</p></div>',
		__( 'The Google Analytics Analyze plugin requires that your server is '.
			'running PHP version 5.3.0 or above.', 'google-analytics-analyze' )
	);
}
// End of file: google-analytics-analyze.php
// Location: google-analytics-analyze.php